@@ -6,7 +6,7 @@
 import os
 from pathlib import Path
 
-from _collection_methods import (
+from ._collection_methods import (
     list_collections,
     get_collection_by_name,
     get_collection_by_id,
@@ -23,20 +23,20 @@ from _collection_methods import (
     _get_image_meta_lookup
 )
 
-from _row_methods import (
+from ._row_methods import (
     get_rows,
     get_rows_by_tag,
     get_rows_by_filter,
 )
 
-from _image_methods import (
+from ._image_methods import (
     get_image_urls,
     list_image_sources,
     download_image,
     download_image_batch,
 )
 
-from _annotation_methods import (
+from ._annotation_methods import (
     get_annotations_for_collection,
     get_annotations_for_image,
     post_annotation,
@@ -44,7 +44,7 @@ from _annotation_methods import (
     _reconstitute_mask,
 )
 
-from _util_methods import (
+from ._util_methods import (
     _get_token,
     _check_status,
     _auth_get,
